#!/bin/bash
DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
LOG=$DIR/current_run.txt
GOLDEN_FILE=$DIR/golden_data.txt

function error()
{
    networksetup -setnetworkserviceenabled Wi-Fi off
    networksetup -setnetworkserviceenabled Ethernet off
    echo $message
    sleep 60
    osascript -e "display notification \"$message\" with title \"Messages and Facetime may not work!!\" sound name \"Glass\""
    exit 1
}

exec >$DIR/imessage_check.log 2>&1

if [[ ! -f $GOLDEN_FILE ]]
then
   echo "No golden file. Assuming first run and will generate golden data. Run one more time after done to perform a check"
   LOG=$GOLDEN_FILE
fi

/Applications/Hackintosh/imessage_debug 2>&1 | awk -F] '{print $2}' > $LOG 
puid=`ioreg -lw0 | grep PlatformUUID | head -1 | sed 's/.*=.*"\(.*\)"/\1/' | tee -a $LOG`
huid=`system_profiler -detailLevel basic 2>/dev/null | fgrep 'Hardware UUID' | sed 's/.*: \(.*\)/\1/' |tee -a $LOG`
systemid=`ioreg -p IODeviceTree -n platform | fgrep system | sed 's/.*<\(.*\)>.*/\1/' | tee -a $LOG`

if [[ $LOG == $GOLDEN_FILE ]]
then
   echo "Changing golden data to read only"
   chmod a=r $GOLDEN_FILE
   exit 2
fi 

diff $LOG $GOLDEN_FILE

if [[ $? -ne 0 ]]
then
    message="System ID's have changed!"
    error
fi

if [[ $systemid == $puid ]]
then
    message="system id matches puid!"
    error
fi

if [[ $puid != $huid ]]
then
    message="Platform UUID and Hardware UUID don't match!"
    error
fi
